from pkg_resources import resource_string
import json

# We'll need this to check if something is a string later.
# This isn't great, but it's better than a dependency on six.
try:
    basestring
except NameError:
    basestring = str


class Wordfilter(object):

    """filter out bad words"""

    blacklist = []

    def __init__(self, blacklist=None, datafile=None):
        if isinstance(blacklist, list):
            self.blacklist = blacklist
            return

        if datafile:
            with open(datafile, 'r') as f:
                self.blacklist = f.read().splitlines()

        else:
            data = resource_string('wordfilter', '../badwords.json').decode('utf-8')
            self.blacklist = [s.lower() for s in json.loads(data, 'r')]

    def blacklisted(self, string):
        string = string.lower().strip()
        return any(word in string for word in self.blacklist)

    def add_words(self, lis):
        if isinstance(lis, basestring):
            lis = [lis]

        self.blacklist.extend([s.lower() for s in lis])

    def remove_words(self, lis):
        if isinstance(lis, basestring):
            lis = [lis]

        for s in lis:
            self.blacklist.remove(s.lower())

    def clear_list(self):
        self.blacklist = []

# instantiates instance so functions are available directly from module
_module_instance = Wordfilter()
blacklisted = _module_instance.blacklisted
add_words = _module_instance.add_words
clear_list = _module_instance.clear_list



#!/usr/bin/env python
from setuptools import setup

try:
    readme = open('README.md', 'r').read()
except IOError:
    readme = ''

setup(
    name='wordfilter',

    version='0.2.5',

    description="A small module meant for use in text generators that lets you filter strings for bad words.",

    long_description=readme,

    author='Neil Freeman & Jim Witschey, based on work by Darius Kazemi',

    author_email='darius.kazemi@gmail.com',

    url='http://tinysubversions.com',

    license='MIT',

    package_dir={'wordfilter': 'lib/wordfilter'},

    packages=['wordfilter'],

    zip_safe=False,

    package_data={
        'wordfilter': ['../badwords.json']
    },

    test_suite='test',

    use_2to3=True,

    classifiers=[
        "Programming Language :: Python",
    ],
)
